@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -851,18 +851,21 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
     private static void insertMessage(final String[] mailIds, final MailMessage[] toFill, final int accountId, final String folder, final MailMessage[] mails, final String uiFullname) {
         final UnifiedINBOXUID helper = new UnifiedINBOXUID();
         for (int k = 0; k < mails.length; k++) {
-            final String lookFor = helper.setUID(accountId, folder, mails[k].getMailId()).toString();
-            int pos = -1;
-            for (int l = 0; l < mailIds.length && pos == -1; l++) {
-                final String mailId = mailIds[l];
-                if (lookFor.equals(mailId)) {
-                    pos = l;
+            final MailMessage mail = mails[k];
+            if (null != mail) {
+                final String lookFor = helper.setUID(accountId, folder, mail.getMailId()).toString();
+                int pos = -1;
+                for (int l = 0; l < mailIds.length && pos == -1; l++) {
+                    final String mailId = mailIds[l];
+                    if (lookFor.equals(mailId)) {
+                        pos = l;
+                    }
+                }
+                if (pos != -1) {
+                    toFill[pos] = mail;
+                    mail.setMailId(mailIds[pos]);
+                    mail.setFolder(uiFullname);
                 }
-            }
-            if (pos != -1) {
-                toFill[pos] = mails[k];
-                mails[k].setMailId(mailIds[pos]);
-                mails[k].setFolder(uiFullname);
             }
         }
     }
